==> aoflagger_2.10.0.orig.tar.bz2: aoflagger-2.10.0/src/aoqplot/controllers/antennapagecontroller.h <==
#ifndef ANTENNAE_PAGE_CONTROLLER_H
#define ANTENNAE_PAGE_CONTROLLER_H

#include "../../quality/statisticscollection.h"

#include "../../structures/measurementset.h"

#include "aoqplotpagecontroller.h"

class AntennaePageController : public AOQPlotPageController
{
protected:
	virtual void processStatistics(const StatisticsCollection *statCollection, const std::vector<AntennaInfo> &antennas) override final
	{
		_antennas = antennas;
		const BaselineStatisticsMap &map = statCollection->BaselineStatistics();
		
		vector<std::pair<unsigned, unsigned> > baselines = map.BaselineList();
		for(vector<std::pair<unsigned, unsigned> >::const_iterator i=baselines.begin();i!=baselines.end();++i)
		{
			if(i->first != i->second)
			{
				const DefaultStatistics& stats = map.GetStatistics(i->first, i->second);
				addStatistic(i->first, stats);
				addStatistic(i->second, stats);
			}
		}
	}
	
	virtual const std::map<double, class DefaultStatistics> &getStatistics() const override final
	{
		return _statistics;
	}
	
	virtual void startLine(Plot2D& plot, const std::string &name, const std::string &yAxisDesc) override final
	{
		Plot2DPointSet& pointSet = plot.StartLine(name, "Antenna index", yAxisDesc, false, Plot2DPointSet::DrawColumns);
		
		std::vector<std::string> labels;
		for(std::vector<AntennaInfo>::const_iterator i=_antennas.begin();i!=_antennas.end();++i)
			labels.push_back(i->name);
		pointSet.SetTickLabels(labels);
		pointSet.SetRotateUnits(true);
	}
	
	void addStatistic(unsigned antIndex, const DefaultStatistics& stats)
	{
		std::map<double, DefaultStatistics>::iterator iter = _statistics.find(antIndex);
		if(iter == _statistics.end())
			_statistics.insert(std::pair<double, DefaultStatistics>(antIndex, stats));
		else
			iter->second += stats;
	}
	
private:
	std::map<double, DefaultStatistics> _statistics;
	std::vector<AntennaInfo> _antennas;
};

#endif

==> aoflagger_2.13.0.orig.tar.bz2: aoflagger-2.13.0/src/aoqplot/controllers/antennapagecontroller.h <==
#ifndef ANTENNAE_PAGE_CONTROLLER_H
#define ANTENNAE_PAGE_CONTROLLER_H

#include "../../quality/statisticscollection.h"

#include "../../structures/measurementset.h"

#include "aoqplotpagecontroller.h"

class AntennaePageController : public AOQPlotPageController
{
protected:
	virtual void processStatistics(const StatisticsCollection *statCollection, const std::vector<AntennaInfo> &antennas) override final
	{
		_antennas = antennas;
		const BaselineStatisticsMap &map = statCollection->BaselineStatistics();
		
		vector<std::pair<unsigned, unsigned> > baselines = map.BaselineList();
		for(vector<std::pair<unsigned, unsigned> >::const_iterator i=baselines.begin();i!=baselines.end();++i)
		{
			if(i->first != i->second)
			{
				const DefaultStatistics& stats = map.GetStatistics(i->first, i->second);
				addStatistic(i->first, stats);
				addStatistic(i->second, stats);
			}
		}
	}
	
	virtual const std::map<double, class DefaultStatistics> &getStatistics() const override final
	{
		return _statistics;
	}
	
	virtual void startLine(Plot2D& plot, const std::string &name, int lineIndex, const std::string &yAxisDesc) override final
	{
		Plot2DPointSet& pointSet = plot.StartLine(name, "Antenna index", yAxisDesc, false, Plot2DPointSet::DrawColumns);
		
		std::vector<std::string> labels;
		for(std::vector<AntennaInfo>::const_iterator i=_antennas.begin();i!=_antennas.end();++i)
			labels.push_back(i->name);
		pointSet.SetTickLabels(labels);
		pointSet.SetRotateUnits(true);
	}
	
	void addStatistic(unsigned antIndex, const DefaultStatistics& stats)
	{
		std::map<double, DefaultStatistics>::iterator iter = _statistics.find(antIndex);
		if(iter == _statistics.end())
			_statistics.insert(std::pair<double, DefaultStatistics>(antIndex, stats));
		else
			iter->second += stats;
	}
	
private:
	std::map<double, DefaultStatistics> _statistics;
	std::vector<AntennaInfo> _antennas;
};

#endif
